@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20385 $
+ * $Revision: 21058 $
  * $Author: rjongbloed $
- * $Date: 2008-06-04 12:40:38 +0200 (mer 04 jun 2008) $
+ * $Date: 2008-09-18 07:21:37 +0000 (Thu, 18 Sep 2008) $
  */
 
 #ifndef _PSOCKBUN_H
@@ -77,6 +77,12 @@ class PInterfaceMonitor : public PProcessStartup
 
     /// Return the singleton interface for the network monitor
     static PInterfaceMonitor & GetInstance();
+    
+    /// Change the refresh interval
+    void SetRefreshInterval (unsigned refresh);
+    
+    /// Change whether the monitor thread should run
+    void SetRunMonitorThread (bool runMonitorThread);
 
     /// Start monitoring network interfaces
     bool Start();
@@ -127,6 +133,7 @@ class PInterfaceMonitor : public PProcessStartup
         handles deletion of the filter.
       */
     void SetInterfaceFilter(PInterfaceFilter * filter);
+    bool HasInterfaceFilter() const { return interfaceFilter != NULL; }
     
     virtual void RefreshInterfaceList();
     
@@ -438,7 +445,7 @@ class PMonitoredSocketChannel : public PChannel
     );
 
     /// Get the current interface descriptor being used/
-    const PString & GetInterface();
+    PString GetInterface();
 
     /** Get the local IP address and port for the currently selected interface.
       */
@@ -500,6 +507,7 @@ class PMonitoredSocketChannel : public PChannel
     PIPSocket::Address   lastReceivedAddress;
     WORD                 lastReceivedPort;
     PString              lastReceivedInterface;
+    PMutex               mutex;
 };
 
 
